from aop.api.base import FileItem, BaseApi
from aop.api.transaction.trade_receive_address import AlibabaTradeReceiveAddressGetParam
from aop.api.transaction.trade_buyer_order_list import AlibabaTradeGetBuyerOrderListParam
from aop.api.transaction.trade_buyer_view import AlibabaTradeGetBuyerViewParam
from aop.api.transaction.trade_fast_create_order import AlibabaTradeFastCreateOrderParam

from aop.api.logistics.logistics_trace_info import AlibabaTradeGetLogisticsTraceInfoBuyerViewParam
from aop.api.logistics.logistic_company import AlibabaLogisticsOpQueryLogisticCompanyListParam
